require 'fundraise/project'
require 'fundraise/die'

module Fundraise

describe Project do

  before do
    @initial_funding = 150
    @target = 300    
    @project = Project.new("Project LMN", @target, @initial_funding)
    $stdout = StringIO.new
  end

  it "has an inital default funding of 0" do
    @project = Project.new("Project LMN", @target)

    expect(@project.current_funding).to eq(0)    
  end

  it "has a target funding" do 
    @project = Project.new("Project LMN")    

    expect(@project.target_funding).not_to eq(0)
  end

  it "increases funds by 25 when funds are added" do
    @project.gain

    expect(@project.current_funding).to eq(@initial_funding + 25)
  end   

  it "decreases funding by 15 when funds are removed" do
    @project.lose

    expect(@project.current_funding).to eq(@initial_funding - 15)
  end 

  it "shows funding outstanding" do
    @project.gain(50)

    expect(@project.funding_needed).to eq(@target - (@initial_funding + 50))
  end

  it "is fully funded" do
    @project.lose(@initial_funding)
    @project.gain(@target)
    expect(@project.fully_funded?).to be true
  end

  it "is NOT fully funded" do
    @project.lose(@initial_funding)
    @project.gain(@target-1)
    expect(@project.fully_funded?).to be false
  end
end
end
